import 'dart:math';

import 'package:syncrow_web/pages/analytics/models/air_quality_data_model.dart';
import 'package:syncrow_web/pages/analytics/modules/air_quality/widgets/aqi_type_dropdown.dart';
import 'package:syncrow_web/pages/analytics/params/get_air_quality_distribution_param.dart';
import 'package:syncrow_web/pages/analytics/services/air_quality_distribution/air_quality_distribution_service.dart';

class FakeAirQualityDistributionService implements AirQualityDistributionService {
  final _random = Random();

  @override
  Future<List<AirQualityDataModel>> getAirQualityDistribution(
    GetAirQualityDistributionParam param,
  ) async {
    return Future.delayed(
      const Duration(milliseconds: 400),
      () => List.generate(30, (index) {
        final date = DateTime(2025, 5, 1).add(Duration(days: index));

        final values = _generateRandomPercentages();
        final nullMask = List.generate(6, (_) => _shouldBeNull());

        if (nullMask.every((isNull) => isNull)) {
          nullMask[_random.nextInt(6)] = false;
        }

        final nonNullValues = _redistributePercentages(values, nullMask);

        return AirQualityDataModel(
          date: date,
          data: [
            AirQualityPercentageData(
              type: AqiType.aqi.code,
              percentage: nonNullValues[0],
              name: 'good',
            ),
            AirQualityPercentageData(
              name: 'moderate',
              type: AqiType.co2.code,
              percentage: nonNullValues[1],
            ),
            AirQualityPercentageData(
              name: 'poor',
              percentage: nonNullValues[2],
              type: AqiType.hcho.code,

            ),
            AirQualityPercentageData(
              name: 'unhealthy',
              percentage: nonNullValues[3],
              type: AqiType.pm10.code,
            ),
            AirQualityPercentageData(
              name: 'severe',
              type: AqiType.pm25.code,
              percentage: nonNullValues[4],
            ),
            AirQualityPercentageData(
              name: 'hazardous',
              percentage: nonNullValues[5],
              type: AqiType.co2.code,
            ),
          ],
        );
      }),
    );
  }

  List<double> _redistributePercentages(
    List<double> originalValues,
    List<bool> nullMask,
  ) {
    double nonNullSum = 0;
    for (int i = 0; i < originalValues.length; i++) {
      if (!nullMask[i]) {
        nonNullSum += originalValues[i];
      }
    }

    return List.generate(originalValues.length, (i) {
      if (nullMask[i]) return 0;
      return (originalValues[i] / nonNullSum * 100).roundToDouble();
    });
  }

  bool _shouldBeNull() => _random.nextDouble() < 0.6;

  List<double> _generateRandomPercentages() {
    final values = List.generate(6, (_) => _random.nextDouble());

    final sum = values.reduce((a, b) => a + b);

    return values.map((value) => (value / sum * 100).roundToDouble()).toList();
  }
}
